@@ -57,7 +57,7 @@ public:
 
 		m_clipSVP = 0;
 
-		m_fillColor = Qt::black;
+		m_fillColor = TQt::black;
 
 		m_useFill = true;
 		m_useStroke = false;
