@@ -377,7 +377,7 @@ KURLBarItem * KURLBar::insertDynamicItem(const KURL& url, const TQString& descri
     return item;
 }
 
-void KURLBar::setOrientation( Qt::Orientation orient )
+void KURLBar::setOrientation( TQt::Orientation orient )
 {
     m_listBox->setOrientation( orient );
     setSizePolicy( TQSizePolicy( isVertical() ?
@@ -388,7 +388,7 @@ void KURLBar::setOrientation( Qt::Orientation orient )
                                 TQSizePolicy::Maximum ));
 }
 
-Qt::Orientation KURLBar::orientation() const
+TQt::Orientation KURLBar::orientation() const
 {
     return m_listBox->orientation();
 }
@@ -399,7 +399,7 @@ void KURLBar::setListBox( KURLBarListBox *view )
 
     if ( !view ) {
         m_listBox = new KURLBarListBox( this, "urlbar listbox" );
-        setOrientation( Qt::Vertical );
+        setOrientation( TQt::Vertical );
     }
     else {
         m_listBox = view;
@@ -412,15 +412,15 @@ void KURLBar::setListBox( KURLBarListBox *view )
     paletteChange( palette() );
     m_listBox->setFocusPolicy( TQWidget::TabFocus );
 
-    connect( m_listBox, TQT_SIGNAL( mouseButtonClicked( int, TQListBoxItem *, const TQPoint & ) ),
-             TQT_SLOT( slotSelected( int, TQListBoxItem * )));
-    connect( m_listBox, TQT_SIGNAL( dropped( TQDropEvent * )),
-             this, TQT_SLOT( slotDropped( TQDropEvent * )));
-    connect( m_listBox, TQT_SIGNAL( contextMenuRequested( TQListBoxItem *,
+    connect( m_listBox, TQ_SIGNAL( mouseButtonClicked( int, TQListBoxItem *, const TQPoint & ) ),
+             TQ_SLOT( slotSelected( int, TQListBoxItem * )));
+    connect( m_listBox, TQ_SIGNAL( dropped( TQDropEvent * )),
+             this, TQ_SLOT( slotDropped( TQDropEvent * )));
+    connect( m_listBox, TQ_SIGNAL( contextMenuRequested( TQListBoxItem *,
                                                       const TQPoint& )),
-             TQT_SLOT( slotContextMenuRequested( TQListBoxItem *, const TQPoint& )));
-    connect( m_listBox, TQT_SIGNAL( returnPressed( TQListBoxItem * ) ),
-             TQT_SLOT( slotSelected( TQListBoxItem * ) ));
+             TQ_SLOT( slotContextMenuRequested( TQListBoxItem *, const TQPoint& )));
+    connect( m_listBox, TQ_SIGNAL( returnPressed( TQListBoxItem * ) ),
+             TQ_SLOT( slotSelected( TQListBoxItem * ) ));
 }
 
 void KURLBar::setIconSize( int size )
@@ -520,7 +520,7 @@ TQSize KURLBar::minimumSizeHint() const
 
 void KURLBar::slotSelected( int button, TQListBoxItem *item )
 {
-    if ( button != Qt::LeftButton )
+    if ( button != TQt::LeftButton )
         return;
 
     slotSelected( item );
@@ -877,9 +877,9 @@ void KURLBarListBox::contextMenuEvent( TQContextMenuEvent *e )
     }
 }
 
-void KURLBarListBox::setOrientation( Qt::Orientation orient )
+void KURLBarListBox::setOrientation( TQt::Orientation orient )
 {
-    if ( orient == Qt::Vertical ) {
+    if ( orient == TQt::Vertical ) {
         setColumnMode( 1 );
         setRowMode( Variable );
     }
@@ -985,7 +985,7 @@ KURLBarItemDialog::KURLBarItemDialog( bool allowGlobal, const KURL& url,
     }
     else
         m_appLocal = 0L;
-    connect(m_urlEdit->lineEdit(),TQT_SIGNAL(textChanged ( const TQString & )),this,TQT_SLOT(urlChanged(const TQString & )));
+    connect(m_urlEdit->lineEdit(),TQ_SIGNAL(textChanged ( const TQString & )),this,TQ_SLOT(urlChanged(const TQString & )));
     m_edit->setFocus();
     setMainWidget( box );
 }
