@@ -83,7 +83,7 @@ TQ_EXPORT_PLUGIN(AsteroidStylePlugin);
 AsteroidStyle::AsteroidStyle() : TDEStyle(AllowMenuTransparency)
 {
 	if (tqApp->inherits("TDEApplication")) {
-		connect(tqApp, TQT_SIGNAL(tdedisplayPaletteChanged()), TQT_SLOT(paletteChanged()));
+		connect(tqApp, TQ_SIGNAL(tdedisplayPaletteChanged()), TQ_SLOT(paletteChanged()));
 	}
 
 	backwards = TQApplication::reverseLayout();
@@ -107,7 +107,7 @@ void AsteroidStyle::polish(const TQStyleControlElementData &ceData, ControlEleme
 		wp.setColor(TQColorGroup::Mid, wp.active().color(TQColorGroup::Button).dark(150));	// Which GUI element(s) does this correspond to?
 	
 		bool isProtectedObject = false;
-		TQObject *curparent = TQT_TQOBJECT(w);
+		TQObject *curparent = w;
 		while (curparent) {
 			if (curparent->inherits("KonqFileTip") || curparent->inherits("AppletItem")
 				|| curparent->inherits("KJanusWidget")
@@ -907,7 +907,7 @@ void AsteroidStyle::drawPrimitive(PrimitiveElement pe,
 				}
 			}
 
-			if (p->pen() == Qt::NoPen) {
+			if (p->pen() == TQt::NoPen) {
 				p->setPen(sf & Style_Enabled ? cg.foreground() : cg.light());
 			}
 
@@ -969,7 +969,7 @@ void AsteroidStyle::drawPrimitive(PrimitiveElement pe,
 	}
 }
 
-void AsteroidStyle::drawControl(TQ_ControlElement ce,
+void AsteroidStyle::drawControl(ControlElement ce,
                                 TQPainter *p,
                                 const TQStyleControlElementData &ceData,
                                 ControlElementFlags elementFlags,
@@ -1675,11 +1675,11 @@ void AsteroidStyle::drawControl(TQ_ControlElement ce,
 				} else if (mi->pixmap()) {
 					TQPixmap *pixmap = mi->pixmap();
 					if (pixmap->depth() == 1) {
-						p->setBackgroundMode(Qt::OpaqueMode);
+						p->setBackgroundMode(TQt::OpaqueMode);
 					}
 					p->drawPixmap(xpos, y, *pixmap);
 					if (pixmap->depth() == 1) {
-						p->setBackgroundMode(Qt::TransparentMode);
+						p->setBackgroundMode(TQt::TransparentMode);
 					}
 				}
 			}
@@ -1710,7 +1710,7 @@ void AsteroidStyle::drawControl(TQ_ControlElement ce,
 	}
 }
 
-void AsteroidStyle::drawControlMask(TQ_ControlElement ce,
+void AsteroidStyle::drawControlMask(ControlElement ce,
                                     TQPainter *p,
                                     const TQStyleControlElementData &ceData,
                                     ControlElementFlags elementFlags,
@@ -1757,7 +1757,7 @@ void AsteroidStyle::drawControlMask(TQ_ControlElement ce,
 	}
 }
 
-void AsteroidStyle::drawComplexControl(TQ_ComplexControl cc,
+void AsteroidStyle::drawComplexControl(ComplexControl cc,
                                        TQPainter *p,
                                        const TQStyleControlElementData &ceData,
                                        ControlElementFlags elementFlags,
@@ -1883,7 +1883,7 @@ void AsteroidStyle::drawComplexControl(TQ_ComplexControl cc,
 				int i;
 				for( i=0; i<64; i++ )
 					a.setPoint( i, 0, i*2+1 );
-				p.setPen( Qt::color1 );
+				p.setPen( TQt::color1 );
 				p.drawPoints( a );
 				p.end();
 				TQApplication::flushX();
@@ -1891,7 +1891,7 @@ void AsteroidStyle::drawComplexControl(TQ_ComplexControl cc,
 				p.begin( horizontalLine );
 				for( i=0; i<64; i++ )
 					a.setPoint( i, i*2+1, 0 );
-				p.setPen( Qt::color1 );
+				p.setPen( TQt::color1 );
 				p.drawPoints( a );
 				p.end();
 				TQApplication::flushX();
@@ -2173,7 +2173,7 @@ void AsteroidStyle::drawComplexControl(TQ_ComplexControl cc,
 	}
 }
 
-void AsteroidStyle::drawComplexControlMask(TQ_ComplexControl cc,
+void AsteroidStyle::drawComplexControlMask(ComplexControl cc,
                                            TQPainter *p,
                                            const TQStyleControlElementData &ceData,
                                            const ControlElementFlags elementFlags,
@@ -2373,7 +2373,7 @@ TQRect AsteroidStyle::subRect(SubRect sr, const TQStyleControlElementData &ceDat
 	}
 }
 
-TQRect AsteroidStyle::querySubControlMetrics(TQ_ComplexControl cc,
+TQRect AsteroidStyle::querySubControlMetrics(ComplexControl cc,
                                             const TQStyleControlElementData &ceData,
                                             ControlElementFlags elementFlags,
                                             SubControl sc,
