@@ -48,23 +48,23 @@ public:
 		       SFlags = Style_Default,
 		       const TQStyleOption & = TQStyleOption::Default ) const;
 
-    void drawControl(TQ_ControlElement, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &,
+    void drawControl(ControlElement, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &,
 		     const TQColorGroup &, SFlags = Style_Default,
 		     const TQStyleOption & = TQStyleOption::Default, const TQWidget * = 0 ) const;
-    void drawControlMask(TQ_ControlElement, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &,
+    void drawControlMask(ControlElement, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &,
 			 const TQStyleOption & = TQStyleOption::Default, const TQWidget * = 0) const;
 
     TQRect subRect(SubRect, const TQStyleControlElementData &ceData, const ControlElementFlags elementFlags, const TQWidget *) const;
 
-    void drawComplexControl(TQ_ComplexControl, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &,
+    void drawComplexControl(ComplexControl, TQPainter *, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQRect &,
 			    const TQColorGroup &, SFlags = Style_Default,
 			    SCFlags = SC_All, SCFlags = SC_None,
 			    const TQStyleOption & = TQStyleOption::Default, const TQWidget * = 0 ) const;
 
-    TQRect querySubControlMetrics(TQ_ComplexControl, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, SubControl,
+    TQRect querySubControlMetrics(ComplexControl, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, SubControl,
 				 const TQStyleOption & = TQStyleOption::Default, const TQWidget * = 0 ) const;
 
-    SubControl querySubControl(TQ_ComplexControl, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQPoint &,
+    SubControl querySubControl(ComplexControl, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQPoint &,
 			       const TQStyleOption &data = TQStyleOption::Default, const TQWidget * = 0 ) const;
 
     int pixelMetric(PixelMetric, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, const TQWidget * = 0 ) const;
